package com.yiqi.core.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.core.domain.ClothWashMode;

/**
 * 洗衣方式Service接口
 *
 * @author ruoyi
 * @date 2023-08-09
 */
public interface IClothWashModeService extends IService<ClothWashMode> {
    /**
     * 查询洗衣方式
     *
     * @param id 洗衣方式主键
     * @return 洗衣方式
     */
    public ClothWashMode selectClothWashModeById(Long id);

    /**
     * 查询洗衣方式列表
     *
     * @param clothWashMode 洗衣方式
     * @return 洗衣方式集合
     */
    public List<ClothWashMode> selectClothWashModeList(ClothWashMode clothWashMode);

    /**
     * 新增洗衣方式
     *
     * @param clothWashMode 洗衣方式
     * @return 结果
     */
    public int insertClothWashMode(ClothWashMode clothWashMode);

    /**
     * 修改洗衣方式
     *
     * @param clothWashMode 洗衣方式
     * @return 结果
     */
    public int updateClothWashMode(ClothWashMode clothWashMode);

    /**
     * 批量删除洗衣方式
     *
     * @param ids 需要删除的洗衣方式主键集合
     * @return 结果
     */
    public int deleteClothWashModeByIds(Long[] ids);

    /**
     * 删除洗衣方式信息
     *
     * @param id 洗衣方式主键
     * @return 结果
     */
    public int deleteClothWashModeById(Long id);

    /**
     * 修改洗衣方式状态
     *
     * @param clothWashMode 洗衣方式
     * @return 结果
     */
    public int updateWashModeStatus(ClothWashMode clothWashMode);
}
